[empathy] TplLogEntry(Text) has been renamed to TplEntry(Text)



commit 09a49d81dafe86a68546613cfeee4e2a118cf198
Author: Guillaume Desmottes <guillaume desmottes collabora co uk>
Date:   Thu Jun 10 10:13:09 2010 +0200

    TplLogEntry(Text) has been renamed to TplEntry(Text)

 libempathy-gtk/empathy-chat.c       |    6 +++---
 libempathy-gtk/empathy-log-window.c |    2 +-
 libempathy/empathy-message.c        |   28 ++++++++++++++--------------
 libempathy/empathy-message.h        |    4 ++--
 4 files changed, 20 insertions(+), 20 deletions(-)
---
diff --git a/libempathy-gtk/empathy-chat.c b/libempathy-gtk/empathy-chat.c
index 43fabfb..ffb2c51 100644
--- a/libempathy-gtk/empathy-chat.c
+++ b/libempathy-gtk/empathy-chat.c
@@ -1932,7 +1932,7 @@ chat_input_populate_popup_cb (GtkTextView *view,
 
 #ifdef ENABLE_TPL
 static gboolean
-chat_log_filter (TplLogEntry *log,
+chat_log_filter (TplEntry *log,
 		 gpointer user_data)
 #else
 static gboolean
@@ -1948,7 +1948,7 @@ chat_log_filter (EmpathyMessage *message,
 	const GList *pending;
 
 #ifdef ENABLE_TPL
-	g_return_val_if_fail (TPL_IS_LOG_ENTRY (log), FALSE);
+	g_return_val_if_fail (TPL_IS_ENTRY (log), FALSE);
 #else
 	g_return_val_if_fail (EMPATHY_IS_MESSAGE (message), FALSE);
 #endif /* ENABLE_TPL */
@@ -2016,7 +2016,7 @@ got_filtered_messages_cb (GObject *manager,
 
 	for (l = messages; l; l = g_list_next (l)) {
 		EmpathyMessage *message;
-		g_assert (TPL_IS_LOG_ENTRY (l->data));
+		g_assert (TPL_IS_ENTRY (l->data));
 
 		message = empathy_message_from_tpl_log_entry (l->data);
 		g_object_unref (l->data);
diff --git a/libempathy-gtk/empathy-log-window.c b/libempathy-gtk/empathy-log-window.c
index 625ae8c..6315a3e 100644
--- a/libempathy-gtk/empathy-log-window.c
+++ b/libempathy-gtk/empathy-log-window.c
@@ -384,7 +384,7 @@ got_messages_for_date_cb (GObject *manager,
 	for (l = messages; l; l = l->next) {
 			EmpathyMessage *message;
 
-			g_assert (TPL_IS_LOG_ENTRY (l->data));
+			g_assert (TPL_IS_ENTRY (l->data));
 
 			message = empathy_message_from_tpl_log_entry (l->data);
 			g_object_unref (l->data);
diff --git a/libempathy/empathy-message.h b/libempathy/empathy-message.h
index d8d0c96..d7f29f7 100644
--- a/libempathy/empathy-message.h
+++ b/libempathy/empathy-message.h
@@ -27,7 +27,7 @@
 
 #include <glib-object.h>
 #ifdef ENABLE_TPL
-#include <telepathy-logger/log-entry.h>
+#include <telepathy-logger/entry.h>
 #endif
 
 #include "empathy-contact.h"
@@ -57,7 +57,7 @@ struct _EmpathyMessageClass {
 GType                    empathy_message_get_type          (void) G_GNUC_CONST;
 EmpathyMessage *         empathy_message_new               (const gchar              *body);
 #ifdef ENABLE_TPL
-EmpathyMessage *         empathy_message_from_tpl_log_entry (TplLogEntry             *logentry);
+EmpathyMessage *         empathy_message_from_tpl_log_entry (TplEntry                *logentry);
 #endif /* ENABLE_TPL */
 TpChannelTextMessageType empathy_message_get_tptype        (EmpathyMessage           *message);
 void                     empathy_message_set_tptype        (EmpathyMessage           *message,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libempathy/empathy-message.c b/libempathy/empathy-message.c
index b3234d3..11a926a 100644
--- a/libempathy/empathy-message.c
+++ b/libempathy/empathy-message.c
@@ -32,8 +32,8 @@
 #include <telepathy-glib/account-manager.h>
 
 #include <telepathy-logger/contact.h>
-#include <telepathy-logger/log-entry.h>
-#include <telepathy-logger/log-entry-text.h>
+#include <telepathy-logger/entry.h>
+#include <telepathy-logger/entry-text.h>
 #endif /* ENABLE_TPL */
 
 #include "empathy-message.h"
@@ -262,7 +262,7 @@ empathy_message_new (const gchar *body)
 
 #ifdef ENABLE_TPL
 EmpathyMessage *
-empathy_message_from_tpl_log_entry (TplLogEntry *logentry)
+empathy_message_from_tpl_log_entry (TplEntry *logentry)
 {
 	EmpathyMessage *retval = NULL;
 	TpAccountManager *acc_man = NULL;
@@ -271,7 +271,7 @@ empathy_message_from_tpl_log_entry (TplLogEntry *logentry)
 	TplContact *sender = NULL;
 	gchar *body= NULL;
 
-	g_return_val_if_fail (TPL_IS_LOG_ENTRY (logentry), NULL);
+	g_return_val_if_fail (TPL_IS_ENTRY (logentry), NULL);
 
 	acc_man = tp_account_manager_dup ();
 	/* FIXME Currently Empathy shows in the log viewer only valid accounts, so it
@@ -286,24 +286,24 @@ empathy_message_from_tpl_log_entry (TplLogEntry *logentry)
 	 * needed anymore any TpAccount passing and the following call will be
 	 * useless */
 	account = tp_account_manager_ensure_account (acc_man,
-			tpl_log_entry_get_account_path (logentry));
+			tpl_entry_get_account_path (logentry));
 	g_object_unref (acc_man);
 
 	/* TODO Currently only TplLogEntryText exists as subclass of TplLogEntry, in
 	 * future more TplLogEntry will exist and EmpathyMessage should probably
 	 * be enhanced to support other types of log entries (ie TplLogEntryCall).
 	 *
 	 * For now we just check (simply) that we are dealing with the only supported type,
 	 * then there will be a if/then/else or switch handling all the supported
 	 * cases.
 	 */
-	if (!TPL_IS_LOG_ENTRY_TEXT (logentry))
+	if (!TPL_IS_ENTRY_TEXT (logentry))
 		return NULL;
 
-	body = g_strdup (tpl_log_entry_text_get_message (
-				TPL_LOG_ENTRY_TEXT (logentry)));
-	receiver = tpl_log_entry_get_receiver (logentry);
-	sender = tpl_log_entry_get_sender (logentry);
+	body = g_strdup (tpl_entry_text_get_message (
+				TPL_ENTRY_TEXT (logentry)));
+	receiver = tpl_entry_get_receiver (logentry);
+	sender = tpl_entry_get_sender (logentry);
 
 	retval = empathy_message_new (body);
 	if (receiver != NULL)
@@ -314,9 +314,9 @@ empathy_message_from_tpl_log_entry (TplLogEntry *logentry)
 				empathy_contact_from_tpl_contact (account, sender));
 
 	empathy_message_set_timestamp (retval,
-			tpl_log_entry_get_timestamp (logentry));
+			tpl_entry_get_timestamp (logentry));
 	empathy_message_set_id (retval,
-			tpl_log_entry_get_pending_msg_id (logentry));
+			tpl_entry_text_get_pending_msg_id (TPL_ENTRY_TEXT (logentry)));
 	empathy_message_set_is_backlog (retval, FALSE);
 
 	g_free (body);
@@ -286,24 +286,24 @@ empathy_message_from_tpl_log_entry (TplLogEntry *logentry)
 	g_object_unref (acc_man);
 
-	/* TODO Currently only TplLogEntryText exists as subclass of TplLogEntry, in
-	 * future more TplLogEntry will exist and EmpathyMessage should probably
+	/* TODO Currently only TplLogEntryText exists as subclass of TplEntry, in
+	 * future more TplEntry will exist and EmpathyMessage should probably
 	 * be enhanced to support other types of log entries (ie TplLogEntryCall).
 	 *